@@ -34,8 +34,8 @@ class OAuthSuite(BaseSuite):
         pass
 
     def create_app(self):
-        client_app = Sanic(__name__)
-        server_app = Sanic(__name__)
+        client_app = Sanic("{}_client".format(self.id()))
+        server_app = Sanic("{}_server".format(self.id()))
         spf1 = SanicPluginsFramework(client_app)
         spf2 = SanicPluginsFramework(server_app)
         return server_app, client_app
