@@ -58,8 +58,8 @@ def test_encode_request_data():
     assert f == 'application/x-www-form-urlencoded'
 
 
-def test_app():
-    app = Sanic(__name__)
+def test_app(request):
+    app = Sanic(request.node.name)
     spf = SanicPluginsFramework(app)
     oauth = spf.register_plugin(oauthclient)
     remote = oauth.remote_app(
@@ -90,9 +90,9 @@ async def test_parse_xml():
 
 
 
-def test_raise_app():
+def test_raise_app(request):
     with raises(AttributeError):
-        app = Sanic(__name__)
+        app = Sanic(request.node.name)
         spf = SanicPluginsFramework(app)
         oauth = spf.register_plugin(oauthclient)
         plugin = app.extensions['oauthlib.client']
@@ -116,7 +116,7 @@ class TestOAuthRemoteApp(object):
             app_key='twitter'
         )
         assert twitter.base_url == 'https://api.twitter.com/1/'
-        app = Sanic(__name__)
+        app = Sanic("test_lazy_load")
         app.config.update({
             'twitter': dict(
                 request_token_params={'realms': 'email'},
@@ -140,7 +140,7 @@ class TestOAuthRemoteApp(object):
     def test_lazy_load_with_plain_text_config(self):
         twitter = oauthclient.remote_app('twitter', app_key='TWITTER')
 
-        app = Sanic(__name__)
+        app = Sanic("test_lazy_load_with_plain_text_config")
         app.config['TWITTER_CONSUMER_KEY'] = 'twitter key'
         app.config['TWITTER_CONSUMER_SECRET'] = 'twitter secret'
         app.config['TWITTER_REQUEST_TOKEN_URL'] = 'request url'
